You are viewing a plain text version of this content. The canonical link for it is here.
Posted to github@arrow.apache.org by "haohuaijin (via GitHub)" <gi...@apache.org> on 2026/08/04 13:36:19 UTC
Re: [PR] perf(parquet): single-allocation intersect_masks/union_masks for unequal lengths [arrow-rs]
haohuaijin commented on PR #10446:
URL: https://github.com/apache/arrow-rs/pull/10446#issuecomment-5179823238
Hi @alamb @hhhizzz , this pr makes the uneven-length intersection/union copy once instead of twice — 18–34% faster, or 61–83% when the masks aren't byte aligned. Also adds a benchmark for the path. ready for reviews.
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: github-unsubscribe@arrow.apache.org
For queries about this service, please contact Infrastructure at:
users@infra.apache.org